@@ -37,17 +37,18 @@ from places_geocode.app.logger import log_error
 
 # import cython files
 from ctypes import *
-create_convex_array = cdll.LoadLibrary("places_geocode/app/CythonOperations/create_convex_array.cpython-38-darwin.so")
-check_dups = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_dups.cpython-38-darwin.so")
-zip_coordinate = cdll.LoadLibrary("places_geocode/app/CythonOperations/zip_coordinate.cpython-38-darwin.so")
-check_lat_long_length = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_lat_long_length.cpython-38-darwin.so")
-check_address_length = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_address_length.cpython-38-darwin.so")
-zip_coordinates_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/zip_coordinates_elastic.cpython-38-darwin.so")
-create_convex_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/create_convex_elastic.cpython-38-darwin.so")
-coordinate_conv_package = cdll.LoadLibrary("places_geocode/app/CythonOperations/coordinate_conv_package.cpython-38-darwin.so")
-
-#from places_geocode.app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
-#    check_address_length, zip_coordinates_elastic, create_convex_elastic, coordinate_conv_package
+try:
+    create_convex_array = cdll.LoadLibrary("places_geocode/app/CythonOperations/create_convex_array.cpython-38-darwin.so")
+    check_dups = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_dups.cpython-38-darwin.so")
+    zip_coordinate = cdll.LoadLibrary("places_geocode/app/CythonOperations/zip_coordinate.cpython-38-darwin.so")
+    check_lat_long_length = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_lat_long_length.cpython-38-darwin.so")
+    check_address_length = cdll.LoadLibrary("places_geocode/app/CythonOperations/check_address_length.cpython-38-darwin.so")
+    zip_coordinates_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/zip_coordinates_elastic.cpython-38-darwin.so")
+    create_convex_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/create_convex_elastic.cpython-38-darwin.so")
+    coordinate_conv_package = cdll.LoadLibrary("places_geocode/app/CythonOperations/coordinate_conv_package.cpython-38-darwin.so")
+except:
+    from places_geocode.app.dprk_copy import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
+        check_address_length, zip_coordinates_elastic, create_convex_elastic, coordinate_conv_package
 
 
 # noinspection PyCompatibility
